=====
About
=====

The enpt_enmapboxapp Python package provides a graphical user interface for the EnMAP_ processing tool (EnPT_)
developed at the German Research Centre for Geosciences Potsdam (GFZ). The GUI is accessible within the EnMAP-Box_, a
QGIS_ plugin to process imaging spectroscopy data and particularly the hyperspectral EnMAP_ data within the framework
of QGIS_. It allows to parameterize EnPT_ and run the processing chain to generate EnMAP_ Level-2A from Level-1B data.


.. image:: ./images/screenshot_enpt_enmapboxapp_v0.6.0.png
    :width: 1046 px
    :height: 876 px
    :scale: 70 %

.. _EnPT: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT
.. _EnMAP-Box: https://www.enmap.org/data_tools/enmapbox/
.. _EnMAP: https://www.enmap.org/
.. _QGIS: https://www.qgis.org
